module.exports = defineTest({
	description: 'handles default function without id exports wrapped in parens'
});
